@@ -15,7 +15,7 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 #include "par2cmdline.h"
 
@@ -78,6 +78,7 @@ Par2Repairer::~Par2Repairer(void)
 
   delete mainpacket;
   delete creatorpacket;
+  delete headers;
 }
 
 
@@ -1261,7 +1262,7 @@ bool Par2Repairer::VerifySourceFiles(void)
         DiskFile::SplitFilename(filename, path, name);
 
         cout << "Target: \"" << name << "\" - missing." << endl;
-	sig_done.emit(name, 0, sourcefile->GetVerificationPacket()->BlockCount());
+	sig_done.emit(name, 0, sourcefile->GetVerificationPacket() ? sourcefile->GetVerificationPacket()->BlockCount() : 0);
       }
     }
 
@@ -1804,7 +1805,7 @@ bool Par2Repairer::ScanDataFile(DiskFile                *diskfile,    // [in]
       }
     }
   }
-  sig_done.emit(name,count,sourcefile->GetVerificationPacket()->BlockCount()); 
+  sig_done.emit(name,count, sourcefile->GetVerificationPacket() ? sourcefile->GetVerificationPacket()->BlockCount() : 0); 
   sig_progress.emit(1000.0);
   return true;
 }
